# Optimize for build time or performance
%bcond_without release_build

%global debug_package %{nil}

Name:           leftwm
Version:        0.5.4
Release:        1%{?dist}
Summary:        Tiling window manager for Adventurers

License:        MIT
URL:            http://leftwm.org/
Source0:        https://github.com/leftwm/leftwm/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cargo >= 1.83
BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  rust >= 1.83

Recommends:     dmenu

%description
LeftWM is a tiling window manager written in Rust that aims to be stable and
performant. LeftWM is designed to do one thing and to do that one thing well:
be a window manager. LeftWM follows the following mantra:

  * LeftWM is not a compositor.
  * LeftWM is not a lock screen.
  * LeftWM is not a bar. But, there are lots of good bars out there. With
    themes, picking one is as simple as setting a symlink.


%prep
%autosetup
# curl https://sh.rustup.rs -sSf | sh -s -- \
#     --profile minimal \
#     --default-toolchain nightly -y


%build
%dnl export CARGO_HOME=$HOME/.cargo/
%dnl export PATH=$HOME/.cargo/bin/

%if %{with release_build}
%dnl $HOME/.cargo/bin/cargo build --release
cargo build --release
%else
%dnl $HOME/.cargo/bin/cargo build
cargo build
%endif


%install
install -D -p -m 0644 %{name}.desktop -t %{buildroot}%{_datadir}/xsessions/
install -D -p -m 0644 %{name}/doc/%{name}.1 -t %{buildroot}%{_mandir}/man1/

install -D -p -m 0755 \
    target/release/%{name} \
    target/release/%{name}-check \
    target/release/%{name}-command \
    target/release/%{name}-state \
    target/release/%{name}-worker \
    -t %{buildroot}%{_bindir}

mkdir -p %{buildroot}%{_datadir}/%{name}
cp -a themes %{buildroot}%{_datadir}/%{name}/

strip --strip-all %{buildroot}%{_bindir}/*


%files
%license LICENSE.md
%doc README.md CHANGELOG.md
%{_bindir}/%{name}
%{_bindir}/%{name}-*
%{_datadir}/%{name}/
%{_datadir}/xsessions/%{name}.desktop
%{_mandir}/man1/*.1*


%changelog
* Fri Feb 07 2025 Artem Polishchuk <ego.cordatus@gmail.com> - 0.5.4-1
- chore: Update to latest release

* Fri Oct 18 2024 Artem Polishchuk <ego.cordatus@gmail.com> - 0.5.2-1
- chore: Update to latest release

* Thu Nov 16 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.5.1-1
- chore(update): 0.5.1

* Wed Nov 15 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.5.0-1
- chore(update): 0.5.0

* Sat Jun 17 2023 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.2-1
- chore(update): 0.4.2

* Tue Dec 27 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.1-1
- chore(update): 0.4.1

* Thu Oct 06 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.4.0-1
- chore(update): 0.4.0

* Sun Sep 04 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 0.3.0-1
- chore(update): 0.3.0

* Tue Aug 25 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.2.4-1
- Update to 0.2.4

* Sat Feb 08 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.2.2-1
- Update to 0.2.2

* Tue Nov 12 2019 Artem Polishchuk <ego.cordatus@gmail.com> - 0.1.10-1
- Initial package
